/************************************************************************/
/*                                                                 
  Start with example nxt_light_reflected to measure light values.
  black: 700
  white: 500

************************************************************************/

#include <Wire.h>
#include <EVShield.h>
#include <EVShieldAGS.h>
#include <EVs_NXTLight.h>

// setup for this example:
// attach NXT Light Sensor to Port BAS1
// Open the Serial terminal to view results.

EVShield     evshield(0x34,0x36); //  Create shield object
EVs_NXTLight myLight; //  Create our sensor for use in this program

bool driving = true, alternate = true;
unsigned int degrees = 2;

void setup()
{

    Serial.begin(115200);       // start serial for output
    //
    // initialize the shield i2c interface.
    //
    evshield.init( SH_HardwareI2C );

    Serial.println ("--------------------------------------");
    Serial.println ("Starting NXT Light Sensor Reflected Light Test program");
    Serial.println ("--------------------------------------");

    //
    //  initialize the sensor, and tell where it is connected.
    //
    myLight.init( &evshield, SH_BAS1 );
    myLight.setReflected();

    Serial.println("setup done");
    Serial.println("shine or block light going into color sensor to see change in value");
    //
    // Wait until user presses GO button to continue the program
    //
    while (!evshield.getButtonState(BTN_GO)) {
        if (millis() % 1000 < 3) {
            Serial.println("Press GO button to continue");
        }
    }
    // start driving
    evshield.bank_a.motorRunUnlimited( SH_Motor_Both, SH_Direction_Reverse, 15 );
}

void
loop()
{
    //
    // declare variable(s)
    //    
    int light;

    //
    // get the reading(s) from sensor
    //
    light = myLight.readRaw();

    //
    // print the sensor value(s)
    //
    Serial.print("light: "); Serial.println(light);
    if (light<600) { // off track
      evshield.bank_a.motorStop(SH_Motor_1, SH_Next_Action_Float );
    }
    else { // on track
      evshield.bank_a.motorRunUnlimited( SH_Motor_Both, SH_Direction_Reverse, 15 );
    }
    delay(50);
}

